==> hazelcast-spring-1.9.3-sources.jar: com/hazelcast/spring/HazelcastNamespaceHandler.java <==
/* 
 * Copyright (c) 2008-2010, Hazel Ltd. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at 
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package com.hazelcast.spring;

import org.springframework.beans.factory.xml.NamespaceHandlerSupport;

import com.hazelcast.spring.hibernate.CacheProviderBeanDefinitionParser;
import com.hazelcast.spring.hibernate.RegionFactoryBeanDefinitionParser;

public class HazelcastNamespaceHandler extends NamespaceHandlerSupport {

    public void init() {
        registerBeanDefinitionParser("config", new HazelcastConfigBeanDefinitionParser());
        registerBeanDefinitionParser("hazelcast", new HazelcastBeanDefinitionParser());
        registerBeanDefinitionParser("client", new HazelcastClientBeanDefinitionParser());
        
        registerBeanDefinitionParser("hibernate-cache-provider", new CacheProviderBeanDefinitionParser());
        registerBeanDefinitionParser("hibernate-region-factory", new RegionFactoryBeanDefinitionParser());
        
        final String[] types = {"map", "multiMap",
            "queue", "topic", "set", "list",
            "executorService", "idGenerator", "atomicNumber"};
        
        for (final String type : types){
            registerBeanDefinitionParser(type, new HazelcastInstanceBeanDefinitionParser(type));
        }
    }  

}

==> hazelcast-spring-2.0.3-sources.jar: com/hazelcast/spring/HazelcastNamespaceHandler.java <==
/*
 * Copyright (c) 2008-2012, Hazel Bilisim Ltd. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.spring;

import com.hazelcast.spring.hibernate.CacheProviderBeanDefinitionParser;
import com.hazelcast.spring.hibernate.RegionFactoryBeanDefinitionParser;
import org.springframework.beans.factory.xml.NamespaceHandlerSupport;

public class HazelcastNamespaceHandler extends NamespaceHandlerSupport {

    public void init() {
        registerBeanDefinitionParser("config", new HazelcastConfigBeanDefinitionParser());
        registerBeanDefinitionParser("hazelcast", new HazelcastBeanDefinitionParser());
        registerBeanDefinitionParser("client", new HazelcastClientBeanDefinitionParser());
        registerBeanDefinitionParser("hibernate-cache-provider", new CacheProviderBeanDefinitionParser());
        registerBeanDefinitionParser("hibernate-region-factory", new RegionFactoryBeanDefinitionParser());
        final String[] types = {"map", "multiMap",
                "queue", "topic", "set", "list",
                "executorService", "idGenerator", "atomicNumber",
                "countDownLatch", "semaphore"};
        for (final String type : types) {
            registerBeanDefinitionParser(type, new HazelcastInstanceBeanDefinitionParser(type));
        }
    }
}
